==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/cstp/leechcraft_cstp_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar_SY" sourcelanguage="en">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation>إضافة مهمّة</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation>المكان:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation>المكان المحلّي:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation>استكشاف...</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation>أسم الملف:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation>التعليق:</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="89"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation>المكان %1 لا يوجد، هل تريد اختيار غيره؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="92"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation>غير قادر على قراءة المكان %1، هل تريد اختيار غيره؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="95"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation>غير قادر على الكتابة في المكان %1، هل تريد اختيار غيره؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="98"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation>%1 ليس مكان مطلقاً، هل تريد اختيار مكان آخر؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>LeechCraft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="139"/>
        <source>Select directory</source>
        <translation>اختر المكان</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="172"/>
        <source>CSTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="174"/>
        <source>Remove</source>
        <translation>إزالة</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="181"/>
        <source>Remove all</source>
        <translation>إزالة الكل</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="190"/>
        <source>Start</source>
        <translation>بدء</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="197"/>
        <source>Stop</source>
        <translation>إيقاف</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="204"/>
        <source>Start all</source>
        <translation>بدء الكل</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="211"/>
        <source>Stop all</source>
        <translation>إيقاف الكل</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="223"/>
        <source>File exists</source>
        <translation>الملف موجود</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="224"/>
        <source>File %1 already exists, continue download?</source>
        <translation>الملف %1 موجود، استمرار تحميله؟</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="36"/>
        <source>URL</source>
        <translation>المكان</translation>
    </message>
    <message>
        <location filename="core.cpp" line="37"/>
        <source>State</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <location filename="core.cpp" line="38"/>
        <source>Progress</source>
        <translation>التقدّم</translation>
    </message>
    <message>
        <location filename="core.cpp" line="39"/>
        <source>Speed</source>
        <translation>السرعة</translation>
    </message>
    <message>
        <location filename="core.cpp" line="40"/>
        <source>ETA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="41"/>
        <source>DTA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="195"/>
        <source>Could not truncate file </source>
        <translation>غير قادر على تقطيع الملف</translation>
    </message>
    <message>
        <location filename="core.cpp" line="318"/>
        <source>%1% (%2 of %3)</source>
        <translation>%1% (%2 من %3)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="323"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="core.cpp" line="331"/>
        <source>/s</source>
        <translation>ثوان</translation>
    </message>
    <message>
        <location filename="core.cpp" line="430"/>
        <source>Could not open file </source>
        <translation>غير قادر على فتح الملف</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="53"/>
        <source>Idle</source>
        <translation>عاطل</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="169"/>
        <source>Stopped</source>
        <translation>متوفّف</translation>
    </message>
    <message>
        <location filename="task.cpp" line="171"/>
        <source>Finished</source>
        <translation>منتهي</translation>
    </message>
    <message>
        <location filename="task.cpp" line="173"/>
        <source>Running</source>
        <translation>تحميل</translation>
    </message>
    <message>
        <location filename="task.cpp" line="194"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation>المهمّة لَمْ تُشغّلْ بشكل صحيح</translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/cstp/leechcraft_cstp_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar_SY" sourcelanguage="en">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation>إضافة مهمّة</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation>المكان:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation>المكان المحلّي:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation>استكشاف...</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation>أسم الملف:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation>التعليق:</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation>المكان %1 لا يوجد، هل تريد اختيار غيره؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation>غير قادر على قراءة المكان %1، هل تريد اختيار غيره؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation>غير قادر على الكتابة في المكان %1، هل تريد اختيار غيره؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation>%1 ليس مكان مطلقاً، هل تريد اختيار مكان آخر؟</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation>اختر المكان</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="201"/>
        <source>Remove</source>
        <translation>إزالة</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="208"/>
        <source>Remove all</source>
        <translation>إزالة الكل</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="217"/>
        <source>Start</source>
        <translation>بدء</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="224"/>
        <source>Stop</source>
        <translation>إيقاف</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="231"/>
        <source>Start all</source>
        <translation>بدء الكل</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="238"/>
        <source>Stop all</source>
        <translation>إيقاف الكل</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="250"/>
        <source>File exists</source>
        <translation>الملف موجود</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="251"/>
        <source>File %1 already exists, continue download?</source>
        <translation>الملف %1 موجود، استمرار تحميله؟</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="61"/>
        <source>URL</source>
        <translation>المكان</translation>
    </message>
    <message>
        <location filename="core.cpp" line="62"/>
        <source>State</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <location filename="core.cpp" line="63"/>
        <source>Progress</source>
        <translation>التقدّم</translation>
    </message>
    <message>
        <location filename="core.cpp" line="412"/>
        <source>%1 (ETA: %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="424"/>
        <source>%1% (%2 of %3 at %4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="575"/>
        <source>Download finished: %1
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="516"/>
        <source>Could not open file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="277"/>
        <source>Could not truncate file </source>
        <translation>غير قادر على تقطيع الملف</translation>
    </message>
    <message>
        <location filename="core.cpp" line="430"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="core.cpp" line="428"/>
        <source>/s</source>
        <translation>ثوان</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation>عاطل</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="213"/>
        <source>Stopped</source>
        <translation>متوفّف</translation>
    </message>
    <message>
        <location filename="task.cpp" line="215"/>
        <source>Finished</source>
        <translation>منتهي</translation>
    </message>
    <message>
        <location filename="task.cpp" line="217"/>
        <source>Running</source>
        <translation>تحميل</translation>
    </message>
    <message>
        <location filename="task.cpp" line="238"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation>المهمّة لَمْ تُشغّلْ بشكل صحيح</translation>
    </message>
    <message>
        <location filename="task.cpp" line="476"/>
        <source>Error writing to file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
